@@ -16,7 +16,7 @@ pub mod as_string {
         T: std::fmt::Display,
         S: Serializer,
     {
-        serializer.collect_str(value)
+        serializer.serialize_str(value.to_string().as_str())
     }
 
     pub fn deserialize<'de, T, D>(deserializer: D) -> Result<T, D::Error>
